@@ -648,6 +648,15 @@ GSM_Error SMSD_ConfigureLogging(GSM_SMSDConfig *Config, gboolean uselog)
 	return ERR_NONE;
 }
 
+/**
+ * Forces using global debug for smsd.
+ */
+void SMSD_EnableGlobalDebug(GSM_SMSDConfig *Config)
+{
+	/* Gammu library wide logging to our log */
+	GSM_SetDebugFunction(SMSD_Log_Function, Config, GSM_GetGlobalDebug());
+}
+
 /**
  * Reads configuration file and feeds it's content into SMSD configuration structure.
  */
@@ -763,9 +772,6 @@ GSM_Error SMSD_ReadConfig(const char *filename, GSM_SMSDConfig *Config, gboolean
 	GSM_SetConfigNum(Config->gsm, 1);
 	gammucfg->UseGlobalDebugFile = FALSE;
 
-	/* Gammu library wide logging to our log */
-	GSM_SetDebugFunction(SMSD_Log_Function, Config, GSM_GetGlobalDebug());
-
 	/* Force debug level in Gammu */
 	if ((DEBUG_GAMMU & Config->debug_level) != 0) {
 		strcpy(gammucfg->DebugLevel, "textall");
